@@ -37,7 +37,7 @@ class DailyTask:
             while True:
                 cls.__sleep_till_start(start_s, stop_s, utc=utc)
                 cls.__wrapper_func(function=function, __timeout=ktime.today_seconds_till(stop_s, utc=utc), *args, **kwargs)
-                cls.__sleep_till_start(start_s, stop_s, utc=utc, force=True)
+                cls.__sleep_till_start(start_s, None, utc=utc)
         except KeyboardInterrupt:
             exit(0)
 
@@ -48,28 +48,30 @@ class DailyTask:
     def __sleep_till_start(
         cls,
         start_s: float,
-        stop_s: float,
-        utc: bool,
-        force: bool = False
+        stop_s: Optional[float],
+        utc: bool
     ) -> None:
+        if stop_s and ktime.is_between_seconds(start_s, stop_s, utc):
+            return
+
         log = Logger()
-        started = False
-        stop_time_str = ktime.seconds_to_time_str(stop_s)
+        start_time_str = ktime.seconds_to_time_str(start_s)
+        seconds_till_start = ktime.today_seconds_till(start_s, utc=utc)
 
         try:
-            while not ktime.is_between_seconds(start_s, stop_s, utc=utc) or force:
-                if not started:
-                    started = True
-                    log.start_process(
-                        'Sleeping ~ {} hours till {}'.format(
-                            round(ktime.today_seconds_till(start_s, utc=utc)/ktime.seconds_in_hour),
-                            stop_time_str
-                        )
-                    )
+            sleep_start_s = time.time()
+            log.start_process(
+                'Sleeping ~ {} hour(s) till {}'.format(
+                    round(seconds_till_start/ktime.seconds_in_hour),
+                    start_time_str
+                )
+            )
 
+            while not ktime.is_between_seconds(start_s, stop_s, utc) if stop_s else ktime.today_seconds_till(start_s, utc=utc) > 0:
                 time.sleep(1)
 
             log.stop_process()
+            log.info('Finished sleeping - {}'.format(ktime.seconds_to_time_str(int(time.time()-sleep_start_s))))
         except KeyboardInterrupt:
             log.stop_process()
 
